% CMIP5 data
%% WOA 13
lon=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','lon');
lat=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','lat');
ix=find(lon>30 & lon<79); lon=lon(ix); % just AS 
iy=find(lat>-40 &lat<30);  lat=lat(iy);
depth=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','depth'); 
depth_bnds=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','depth_bnds');

% oxygen in ml/l
oxygen=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','o_an');
oxygen_woa=oxygen(ix,iy,:,:)*40;  % in umol/l
clear oxygen

%% volume calculation
dA=(2*pi*6371/360)^2*cosd(lat)*1000000; %in m
dz=diff(depth_bnds)';

V=permute(repmat(dA,[1 length(lon) length(dz)]),[2 1 3])...
              .*permute(repmat(dz,[1 length(lon) length(lat)]),[2 3 1]);
        
V_woa=V; V_woa(isnan(oxygen_woa))=NaN; 

for kstep=5:5:100 % oxygen threshold
    V_loop=V_woa; 
    V_loop(oxygen_woa>=kstep)=NaN; % suboxia <0.01 mol/m^3 = 10 umol/l
    V_loop=squeeze(nansum(nansum(nansum(V_loop,1),2),3));
    V_woa_threshold(kstep/5)=V_loop;
end

cd /Volumes/Geomar_data/ % Laptop mit Festplatte
list2= [...
%     'CESM1-BGC   ';...
    'GFDL-ESM2G  ';...
%     'GFDL-ESM2M  ';...
    'HadGEM2-CC  ';...
%     'IPSL-CM5A-LR';...
    'IPSL-CM5A-MR';...
%     'MPI-ESM-LR  ';...
    'MPI-ESM-MR  ';...
%     'MRI-ESM1    ';...
    'NorESM1-ME  ';...
    ];
list1= [...
    'CESM1-BGC   ';...   
%     'GFDL-ESM2G  ';...
    'GFDL-ESM2M  ';...
%     'HadGEM2-CC  ';...
    'IPSL-CM5A-LR';...
%     'IPSL-CM5A-MR';...
    'MPI-ESM-LR  ';...
%     'MPI-ESM-MR  ';...
    'MRI-ESM1    ';...
%     'NorESM1-ME  ';...
    ];
% color
colors=[0 .3 .7 1;0.8510    0.3725    0.0078 1;0.8510    0.3725    0.0078 .4;0 .3 .7 .4;.106 .62 .47 1];

%% different thresholds
fig=figure(1);
clf
sp1=subplot(1,3,1);
hold on

for istep=1:size(list1,1)
    % load data list1
    oxygen_tmean=ncread([strcat(list1(istep,:)) '/gridint_woa13_' strcat(list1(istep,:)) '_o2_tmean_1900-1999.nc'],'O2NEW');
    oxygen_tmean=oxygen_tmean(ix,iy,:)*1000;
    V_model=V; V_model(isnan(oxygen_tmean))=NaN; 
    
    for kstep=5:5:100 % oxygen threshold
        V_loop=V_model; 
        V_loop(oxygen_tmean>=kstep)=NaN; % suboxia <0.01 mol/m^3 = 10 umol/l
        V_loop=squeeze(nansum(nansum(nansum(V_loop,1),2),3));
        V_model_threshold(istep,kstep/5)=V_loop;
    end
    plot([5:5:100],V_model_threshold(istep,:)/10000000000000000,'linewidth',3,'color',colors(istep,:))
    
    % load data list2
    oxygen_tmean=ncread([strcat(list2(istep,:)) '/gridint_woa13_' strcat(list2(istep,:)) '_o2_tmean_1900-1999.nc'],'O2NEW');
    oxygen_tmean=oxygen_tmean(ix,iy,:)*1000;
    V_model=V; V_model(isnan(oxygen_tmean))=NaN; 
    
    for kstep=5:5:100 % oxygen threshold
        V_loop=V_model; 
        V_loop(oxygen_tmean>=kstep)=NaN; % suboxia <0.01 mol/m^3 = 10 umol/l
        V_loop=squeeze(nansum(nansum(nansum(V_loop,1),2),3));
        V_model_threshold(istep,kstep/5)=V_loop;
    end
    plot([5:5:100],V_model_threshold(istep,:)/10000000000000000,'linewidth',3,'color',colors(istep,:),'linestyle','--')
end
    
  
plot([5:5:100],V_woa_threshold/10000000000000000,'linewidth',5,'color','k')
xlim([5 100]); xlabel('Oxygen threshold [\mumol/l]')
ylabel('Volume [10^{16}m^3]')
grid on
box on
set(gca,'FontSize', 20)
text(80,1.8,'(a)','FontSize', 20)
%% area/depth
dA=(2*pi*6371/360)^2*cosd(lat)*1000000; %in m
A=permute(repmat(dA,[1 length(lon)]),[2 1]);

% define oxygen threshold
oxy_theshold=50;
 
sp2=subplot(1,3,2);
hold on

for istep=1:size(list1,1)
    % load data
    oxygen_tmean=ncread([strcat(list1(istep,:)) '/gridint_woa13_' strcat(list1(istep,:)) '_o2_tmean_1900-1999.nc'],'O2NEW');
    oxygen_tmean=oxygen_tmean(ix,iy,:)*1000;
    for kstep=1:length(depth)
        isOMZ_model=(oxygen_tmean(:,:,kstep))<=oxy_theshold; % mask model
        
        A_model=A;  % remove land
        A_model=A_model.*isOMZ_model; A_model=squeeze(nansum(nansum(nansum(A_model,1),2),3));
        A_cabre(istep,kstep)=A_model;
    end

    plot(A_cabre(istep,:)/1000000000000,depth,'linewidth',3,'color',colors(istep,:))
    
    % load data
    oxygen_tmean=ncread([strcat(list2(istep,:)) '/gridint_woa13_' strcat(list2(istep,:)) '_o2_tmean_1900-1999.nc'],'O2NEW');
    oxygen_tmean=oxygen_tmean(ix,iy,:)*1000;
    for kstep=1:length(depth)
        isOMZ_model=(oxygen_tmean(:,:,kstep))<=oxy_theshold; % mask model
        
        A_model=A;  % remove land
        A_model=A_model.*isOMZ_model; A_model=squeeze(nansum(nansum(nansum(A_model,1),2),3));
        A_cabre(istep,kstep)=A_model;
    end

    plot(A_cabre(istep,:)/1000000000000,depth,'linewidth',3,'color',colors(istep,:),'linestyle','--')
end
    
for kstep=1:length(depth)
        isOMZ_woa=oxygen_woa(:,:,kstep)<=oxy_theshold; % mask observations
        
        A_woa=A; 
        A_woa=A_woa.*isOMZ_woa; A_woa=squeeze(nansum(nansum(nansum(A_woa,1),2),3));   
        A_obs(kstep)=A_woa;
end
    plot(A_obs/1000000000000,depth,'linewidth',5,'color','k')
    text(4.5,1800,'oxygen<50\mumol/l', 'FontSize',20)
axis ij
lgd=legend({'\color[rgb]{0 .3 .7 1}CESM1-BGC','\color[rgb]{0 .3 .7 1}GFDL-ESM2G','\color[rgb]{0.8510    0.3725    0.0078 1}GFDL-ESM2M','\color[rgb]{0.8510    0.3725    0.0078 1}HadGEM2-ES',...
    '\color[rgb]{0.8510    0.3725    0.0078 .4}IPSL-CM5A-LR','\color[rgb]{0.8510    0.3725    0.0078 .4}IPSL-CM5A-MR','\color[rgb]{0 .3 .7 .4}MPI-ESM-LR','\color[rgb]{0 .3 .7 .4}MPI-ESM-MR',...
    '\color[rgb]{.106 .62 .4}MRI-ESM1','\color[rgb]{.106 .62 .4}NorESM1-ME','WOA'},'Location','eastoutside','Fontsize',20)
legend('boxoff')
grid on
box on
xlim([0 12]); 
xlabel('Area [10^{12}m^2]')
ylim([0 2000]); ylabel('Depth [m]')
set(gca,'FontSize', 20)
text(10,200,'(b)','FontSize', 20)

%% map with horizontal extension
depthindex=find(depth==500);


sp3=subplot(1,3,3);
m_proj('miller','lat',[-25 30],'lon',[30 79]);
hold on
for istep=1:size(list1,1)
    oxygen_tmean=ncread([strcat(list1(istep,:)) '/gridint_woa13_' strcat(list1(istep,:)) '_o2_tmean_1900-1999.nc'],'O2NEW');
    oxygen_tmean=oxygen_tmean(ix,iy,:)*1000;
    
    m_contour(lon,lat,squeeze(oxygen_tmean(:,:,depthindex))','levellist',50,'color',colors(istep,1:3),'linewidth',3)
    
    oxygen_tmean=ncread([strcat(list2(istep,:)) '/gridint_woa13_' strcat(list2(istep,:)) '_o2_tmean_1900-1999.nc'],'O2NEW');
    oxygen_tmean=oxygen_tmean(ix,iy,:)*1000;
    
    m_contour(lon,lat,squeeze(oxygen_tmean(:,:,depthindex))','levellist',50,'color',colors(istep,1:3),'linewidth',3,'linestyle','--')
end
    
m_contour(lon,lat,squeeze(oxygen_woa(:,:,depthindex))','levellist',50,'color','k','linewidth',5)
m_coast('color','k')
m_grid('FontSize', 20)
m_text(65,-20,'z=500m','FontSize', 20)
m_text(72,25,'(c)','FontSize', 20)



