% Cluster analysis for oxygen of the Cmip5 models in the Indian Ocean

clear all
%% load data
% define list of model names
% -> model data load later in a loop
list= [...
    'CESM1-BGC   ';...
    'GFDL-ESM2G  ';...
    'GFDL-ESM2M  ';...
    'HadGEM2-CC  ';...
    'IPSL-CM5A-LR';...
    'IPSL-CM5A-MR';...
    'MPI-ESM-LR  ';...
    'MPI-ESM-MR  ';...
    'MRI-ESM1    ';...
    'NorESM1-ME  ';...
    ];

% WOA 13
lon=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','lon');
lat=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','lat');
ix=find(lon<=67&lon>=61); lon=lon(ix);
iy=find(lat>=16&lat<=22);  lat=lat(iy);
depth=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','depth');
depth_bnds=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','depth_bnds');

% oxygen in ml/l
oxygen=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','o_an');
oxygen_woa=oxygen(ix,iy,:,:)*40;  % in umol/l

%salinity
salinity=ncread('/Volumes/Geomar_data/WOA13/salinity/woa13_decav_s00_01v2.nc','s_an');
salinity_woa=salinity(ix,iy,:,:);

%% create depth profiles of data in the Arabain Sea
oxygen_woa=squeeze(nanmean(nanmean(oxygen_woa,1),2));
salinity_woa=squeeze(nanmean(nanmean(salinity_woa,1),2));
%% load data and plot profiles
cd /Volumes/Geomar_data/

A=zeros(size(list,1),length(oxygen_woa));
for istep=1:size(list,1)
    % load model data
    oxygen=ncread([strcat(list(istep,:)) '/gridint_woa13_' strcat(list(istep,:)) '_o2_tmean_1900-1999.nc'],'O2NEW');
    oxygen=squeeze(nanmean(nanmean(oxygen(ix,iy,:),1),2))*1000;
    
    A(istep,:)=oxygen; % model oxygen data matrix
end
clear oxygen


%%

%-------------------------------------
% CLUSTERANALYSIS
%-------------------------------------

% Introduce distance measure
diff=zeros(size(list,1)+1,size(list,1)+1)
for i=1:size(list,1)
 for j=1:size(list,1)
% Take shape/correlation as distance measure
c1=(corrcoef(A(i,3:63),A(j,3:63)));
c2=corrcoef(oxygen_woa(3:63)',A(j,3:63));
c3=(corrcoef(oxygen_woa(3:63)',A(i,3:63)));
diff(i+1,j+1)=1-c1(1,2);
diff(1,j+1)=1-c2(1,2);
diff(i+1,1)=1-c3(1,2);
diff(i,i)=0;
diff(end,end)=0;
end
end
diff

y=squareform(diff)

Z=linkage(y)
c = cluster(Z,'Maxclust',4)


%% plot 

cd /Volumes/Geomar_data/ 

fig=figure(1);
clf 
sp1=subplot(1,2,1);
plot(oxygen_woa,depth,'LineWidth',5,'Color','k')
hold on

oxygen=ncread(['CESM1-BGC/gridint_woa13_CESM1-BGC_o2_tmean_1900-1999.nc'],'O2NEW');
oxygen=squeeze(nanmean(nanmean(oxygen(ix,iy,:),1),2))*1000;
plot(oxygen,depth,'LineWidth',3,'color',[0 .3 .7 1])  

oxygen=ncread(['GFDL-ESM2G/gridint_woa13_GFDL-ESM2G_o2_tmean_1900-1999.nc'],'O2NEW');
oxygen=squeeze(nanmean(nanmean(oxygen(ix,iy,:),1),2))*1000;
plot(oxygen,depth,'LineWidth',3,'color',[0 .3 .7 1],'linestyle','--')  

oxygen=ncread(['GFDL-ESM2M/gridint_woa13_GFDL-ESM2M_o2_tmean_1900-1999.nc'],'O2NEW');
oxygen=squeeze(nanmean(nanmean(oxygen(ix,iy,:),1),2))*1000;
plot(oxygen,depth,'LineWidth',3,'color',[0.8510    0.3725    0.0078 1])  

oxygen=ncread(['HadGEM2-CC/gridint_woa13_HadGEM2-CC_o2_tmean_1900-1999.nc'],'O2NEW');
oxygen=squeeze(nanmean(nanmean(oxygen(ix,iy,:),1),2))*1000;
plot(oxygen,depth,'LineWidth',3,'color',[0.8510    0.3725    0.0078 1],'linestyle','--')  

oxygen=ncread(['IPSL-CM5A-LR/gridint_woa13_IPSL-CM5A-LR_o2_tmean_1900-1999.nc'],'O2NEW');
oxygen=squeeze(nanmean(nanmean(oxygen(ix,iy,:),1),2))*1000;
plot(oxygen,depth,'LineWidth',3,'color',[0.8510    0.3725    0.0078 .4])  

oxygen=ncread(['IPSL-CM5A-MR/gridint_woa13_IPSL-CM5A-MR_o2_tmean_1900-1999.nc'],'O2NEW');
oxygen=squeeze(nanmean(nanmean(oxygen(ix,iy,:),1),2))*1000;
plot(oxygen,depth,'LineWidth',3,'color',[0.8510    0.3725    0.0078 .4],'linestyle','--')  

oxygen=ncread(['MPI-ESM-LR/gridint_woa13_MPI-ESM-LR_o2_tmean_1900-1999.nc'],'O2NEW');
oxygen=squeeze(nanmean(nanmean(oxygen(ix,iy,:),1),2))*1000;
plot(oxygen,depth,'LineWidth',3,'color',[0 .3 .7 .4])  

oxygen=ncread(['MPI-ESM-MR/gridint_woa13_MPI-ESM-MR_o2_tmean_1900-1999.nc'],'O2NEW');
oxygen=squeeze(nanmean(nanmean(oxygen(ix,iy,:),1),2))*1000;
plot(oxygen,depth,'LineWidth',3,'color',[0 .3 .7 .4],'linestyle','--')  

oxygen=ncread(['MRI-ESM1/gridint_woa13_MRI-ESM1_o2_tmean_1900-1999.nc'],'O2NEW');
oxygen=squeeze(nanmean(nanmean(oxygen(ix,iy,:),1),2))*1000;
plot(oxygen,depth,'LineWidth',3,'color', [.106 .62 .47])  

oxygen=ncread(['NorESM1-ME/gridint_woa13_NorESM1-ME_o2_tmean_1900-1999.nc'],'O2NEW');
oxygen=squeeze(nanmean(nanmean(oxygen(ix,iy,:),1),2))*1000;
plot(oxygen,depth,'LineWidth',3,'color',[.106 .62 .4],'linestyle','--')  


ylim([0 3700])
xlim([0 295])
axis ij
set(gca,'FontSize', 25)
xlabel('Oxygen concentration [\mumol/l]')
ylabel('Depth [m]')
% title('Oxygen profiles in the OMZ of the Arabian Sea')
text(260,300,'(a)','FontSize', 25)

%%
sp2=subplot(1,2,2);
plot(salinity_woa,depth,'LineWidth',5,'Color','k')
hold on

salinity=ncread(['CESM1-BGC/gridint_woa13_CESM1-BGC_so_tmean_1900-1999.nc'],'SONEW');
salinity=squeeze(nanmean(nanmean(salinity(ix,iy,:),1),2));
plot(salinity,depth,'LineWidth',3,'color',[0 .3 .7 1])  

salinity=ncread(['GFDL-ESM2G/gridint_woa13_GFDL-ESM2G_so_tmean_1900-1999.nc'],'SONEW');
salinity=squeeze(nanmean(nanmean(salinity(ix,iy,:),1),2));
plot(salinity,depth,'LineWidth',3,'color',[0 .3 .7 1],'linestyle','--')  

salinity=ncread(['GFDL-ESM2M/gridint_woa13_GFDL-ESM2M_so_tmean_1900-1999.nc'],'SONEW');
salinity=squeeze(nanmean(nanmean(salinity(ix,iy,:),1),2));
plot(salinity,depth,'LineWidth',3,'color',[0.8510    0.3725    0.0078 1])  

salinity=ncread(['HadGEM2-CC/gridint_woa13_HadGEM2-CC_so_tmean_1900-1999.nc'],'SONEW');
salinity=squeeze(nanmean(nanmean(salinity(ix,iy,:),1),2));
plot(salinity,depth,'LineWidth',3,'color',[0.8510    0.3725    0.0078 1],'linestyle','--')  

salinity=ncread(['IPSL-CM5A-LR/gridint_woa13_IPSL-CM5A-LR_so_tmean_1900-1999.nc'],'SONEW');
salinity=squeeze(nanmean(nanmean(salinity(ix,iy,:),1),2));
plot(salinity,depth,'LineWidth',3,'color',[0.8510    0.3725    0.0078 .4])  

salinity=ncread(['IPSL-CM5A-MR/gridint_woa13_IPSL-CM5A-MR_so_tmean_1900-1999.nc'],'SONEW');
salinity=squeeze(nanmean(nanmean(salinity(ix,iy,:),1),2));
plot(salinity,depth,'LineWidth',3,'color',[0.8510    0.3725    0.0078 .4],'linestyle','--')  

salinity=ncread(['MPI-ESM-LR/gridint_woa13_MPI-ESM-LR_so_tmean_1900-1999.nc'],'SONEW');
salinity=squeeze(nanmean(nanmean(salinity(ix,iy,:),1),2));
plot(salinity,depth,'LineWidth',3,'color',[0 .3 .7 .4])  

salinity=ncread(['MPI-ESM-MR/gridint_woa13_MPI-ESM-MR_so_tmean_1900-1999.nc'],'SONEW');
salinity=squeeze(nanmean(nanmean(salinity(ix,iy,:),1),2));
plot(salinity,depth,'LineWidth',3,'color',[0 .3 .7 .4],'linestyle','--')  

salinity=ncread(['MRI-ESM1/gridint_woa13_MRI-ESM1_so_tmean_1900-1999.nc'],'SONEW');
salinity=squeeze(nanmean(nanmean(salinity(ix,iy,:),1),2));
plot(salinity,depth,'LineWidth',3,'color', [.106 .62 .47])  

salinity=ncread(['NorESM1-ME/gridint_woa13_NorESM1-ME_so_tmean_1900-1999.nc'],'SONEW');
salinity=squeeze(nanmean(nanmean(salinity(ix,iy,:),1),2));
plot(salinity,depth,'LineWidth',3,'color',[.106 .62 .4],'linestyle','--')  

ylim([0 3700])
axis ij
set(gca,'FontSize', 25, 'yticklabels',[])
xlabel('Salinity')
legend({'WOA','CESM1-BGC','GFDL-ESM2G','GFDL-ESM2M','HadGEM2-ES','IPSL-CM5A-LR','IPSL-CM5A-MR','MPI-ESM-LR','MPI-ESM-MR','MRI-ESM1','NorESM1-ME'},'Location','southeast','FontSize', 20)
legend('boxoff')
text(37.6,300,'(b)','FontSize', 25)

legend({'WOA','\color[rgb]{0 .3 .7 1}CESM1-BGC','\color[rgb]{0 .3 .7 1}GFDL-ESM2G','\color[rgb]{0.8510    0.3725    0.0078 1}GFDL-ESM2M','\color[rgb]{0.8510    0.3725    0.0078 1}HadGEM2-ES',...
    '\color[rgb]{0.8510    0.3725    0.0078 .4}IPSL-CM5A-LR','\color[rgb]{0.8510    0.3725    0.0078 .4}IPSL-CM5A-MR','\color[rgb]{0 .3 .7 .4}MPI-ESM-LR','\color[rgb]{0 .3 .7 .4}MPI-ESM-MR',...
    '\color[rgb]{.106 .62 .4}MRI-ESM1','\color[rgb]{.106 .62 .4}NorESM1-ME'},'Location','southeast','FontSize', 20)

