%% water mass source regions plots
% WOA 13
lon=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','lon');
lat=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','lat');
ix=find(lon>20 & lon<130); lon=lon(ix);
iy=find(lat>-60 &lat<30);  lat=lat(iy);
depth=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','depth');

lonp=lon;
latp=lat;
depthp=depth;

% repmat data
lon=repmat(lon,1,length(lat),length(depth));
lat=permute(repmat(lat,1,size(lon,1),length(depth)),[2,1,3]);
depth=permute(repmat(depth,1,size(lon,1),size(lat,2)),[2,3,1]);

% tempearture
temp=ncread('/Volumes/Geomar_data/WOA13/temperature/woa13_decav_t00_01v2.nc','t_an');
temp=temp(ix,iy,:,:);
% salinity
sal=ncread('/Volumes/Geomar_data/WOA13/salinity/woa13_decav_s00_01v2.nc','s_an');
sal=sal(ix,iy,:,:);

%% observations

index_RSPGW=find(temp>18&sal>37.14);

fig=figure;
sp1=subplot(1,3,1);
        m_proj('miller','lat',[-5 30],'lon',[30 79]);
        m_scatter(lon(index_RSPGW),lat(index_RSPGW),22,double(depth(index_RSPGW)),'filled')
        m_coast('color','k');
        m_grid('linestyle','none','fontsize',16);
        caxis([0 900])
        m_text(72, 26,['(a)'],'Fontsize',16)
        cb1=colorbar;
        set(cb1,'location','southoutside','Fontsize',16)
        xlabel(cb1,'Depth [m]','Fontsize',16)

index_ICW=find(lat<=-16 & lat>=-22 &temp>17&temp<19&sal>35.45&sal<35.5);
sp2=subplot(1,3,2)
       m_proj('miller','longitude',[20 130], 'latitude',[-60 30])
        m_scatter(lon(index_ICW),lat(index_ICW),10,double(depth(index_ICW)),'filled')
        m_coast('color','k');
        m_grid('linestyle','none','fontsize',16);
        caxis([0 250])
        m_text(25, 18,'(b)','Fontsize',16)
        cb2=colorbar;
        set(cb2,'location','southoutside','Fontsize',16)
        xlabel(cb2,'Depth [m]','Fontsize',16)

index_lIODW=find(temp>0&temp<.5&sal>34.65&sal<34.7);
sp3=subplot(1,3,3)
       m_proj('miller','longitude',[20 130], 'latitude',[-60 30])
        m_scatter(lon(index_lIODW),lat(index_lIODW),10,double(depth(index_lIODW)),'filled')
        m_coast('color','k');
        m_grid('linestyle','none','fontsize',16);
        caxis([0 5500])
        m_text(25,18,'(c)','Fontsize',16)
        cb3=colorbar;
        set(cb3,'location','southoutside','Fontsize',16)
        xlabel(cb3,'Depth [m]','Fontsize',16)
        

%% model data 
cd /Volumes/Geomar_data/

list= [...
    'CESM1-BGC   ';...
    'GFDL-ESM2G  ';...
    'GFDL-ESM2M  ';...
    'HadGEM2-CC  ';...
    'IPSL-CM5A-LR';...
    'IPSL-CM5A-MR';...
    'MPI-ESM-LR  ';...
    'MPI-ESM-MR  ';...
    'MRI-ESM1    ';...
    'NorESM1-ME  ';...
    ];

% load values from table
lIODW_temp1=[0.3 -0.9 0.5 0 -0.6 -0.6 0 0 0.7 -0.4];
lIODW_temp2=[0.9 0.2 1.9 1 0.6 0.4 0.8 1.1 1.7 1.2];
lIODW_sal1=[34.58 34.52 34.56 34.69 34.57 34.58 34.58 34.59 34.62 34.66]; 
lIODW_sal2=[34.62 34.66 34.73 34.76 34.63 34.67 34.65 34.68 34.71 34.87];

RSPGW_temp1=[22.8 20 22.8 19.4 18.5 20 22.5 21.8 19.5 20.5];
RSPGW_temp2=[29.0 26.3 28.4 31.19 26.6 28.9 29.3 29.4 26.9 25.3];
RSPGW_sal1=[38.66 37.00 38.19 37.00 39.16 38.90 36.68 36.90 37.82 36.07];
RSPGW_sal2=[43.27 41.07 41.24 44.84 46.55 46.71 39.28 42.45 44.54 41.18];

ICW_temp1=[9.0 9.8 10.3 12.5 7.0 7.1 11.1 10.8 9.5 10.9];
ICW_temp2=[17.1 17.7 18.1 17.9 15.7 16.2 19.2 19.1 17.7 18.8 19.9];
ICW_sal1=[34.98 34.49 34.58 34.47 34.87 34.72 34.52 34.76 34.70 34.50]; 
ICW_sal2=[36.13 35.29 35.30 35.48 35.69 35.53 35.55 35.68 35.91 35.40];

%% IODW

for istep=1:size(list,1)
    % load data
    modeltemp=ncread([strcat(list(istep,:)) '/gridint_woa13_' strcat(list(istep,:)) '_thetao_tmean_1900-1999.nc'],'THETAONEW');
    modeltemp=modeltemp(ix,iy,:)-273.15; % change to celsius
    modelsal=ncread([strcat(list(istep,:)) '/gridint_woa13_' strcat(list(istep,:)) '_so_tmean_1900-1999.nc'],'SONEW');
    modelsal=modelsal(ix,iy,:);
    
    % sourcewatermass locations
    index_lIODW=find(modeltemp>=lIODW_temp1(istep)&modeltemp<=lIODW_temp2(istep)&modelsal>=lIODW_sal1(istep)&modelsal<=lIODW_sal2(istep));
    
    figure
       m_proj('miller','longitude',[20 130], 'latitude',[-60 30])
        m_scatter(lon(index_lIODW),lat(index_lIODW),10,double(depth(index_lIODW)),'filled')
        m_coast('color','k');
        m_grid('linestyle','none','fontsize',20);
        caxis([0 5500])
        m_text(80, -38,['' strcat(list(istep,:)) ''],'Fontsize',20)
        
        print('-painters',['/Users/hschmidt/Desktop/plots_temp/IODW_sourceregion_panel_' strcat(list(istep,:)) ''],'-depsc')
end

% woa
index_lIODW=find(temp>0&temp<.5&sal>34.65&sal<34.7);

figure
       m_proj('miller','longitude',[20 130], 'latitude',[-60 30])
        m_scatter(lon(index_lIODW),lat(index_lIODW),10,double(depth(index_lIODW)),'filled')
        m_coast('color','k');
        m_grid('linestyle','none','fontsize',20);
        caxis([0 5500])
        m_text(80, -38,'WOA13','Fontsize',20)
        cb=colorbar;
        set(cb, 'location','southoutside','Fontsize',20)
        xlabel(cb,'Depth [m]','Fontsize',20)
        
        print('-painters',['/Users/hschmidt/Desktop/plots_temp/IODW_sourceregion_panel_colorbar'],'-depsc')
        
%% ICW

for istep=1:size(list,1)
    % load data
    modeltemp=ncread([strcat(list(istep,:)) '/gridint_woa13_' strcat(list(istep,:)) '_thetao_tmean_1900-1999.nc'],'THETAONEW');
    modeltemp=modeltemp(ix,iy,:)-273.15; % change to celsius
    modelsal=ncread([strcat(list(istep,:)) '/gridint_woa13_' strcat(list(istep,:)) '_so_tmean_1900-1999.nc'],'SONEW');
    modelsal=modelsal(ix,iy,:);
    
    % sourcewatermass locations
    index_ICW=find(lon>=53 & lon<=110 & lat<=-18 & lat>=-22 &modeltemp>=ICW_temp1(istep) &modeltemp<=ICW_temp2(istep)...
                &modelsal>=ICW_sal1(istep) &modelsal<=ICW_sal2(istep));  
            
    figure
        m_proj('miller','longitude',[20 130], 'latitude',[-60 30])
        m_scatter(lon(index_ICW),lat(index_ICW),10,double(depth(index_ICW)),'filled')
        m_coast('color','k');
        m_grid('linestyle','none','fontsize',20);
        caxis([0 800]) 
        m_text(80, -54,['' strcat(list(istep,:)) ''],'Fontsize',20)
        
        print('-painters',['/Users/hschmidt/Desktop/plots_temp/ICW_sourceregion_panel_' strcat(list(istep,:)) ''],'-depsc')

end

% woa
index_ICW=find(lat<=-16 & lat>=-22 &temp>17&temp<19&sal>35.45&sal<35.5);

figure
       m_proj('miller','longitude',[20 130], 'latitude',[-60 30])
        m_scatter(lon(index_ICW),lat(index_ICW),10,double(depth(index_ICW)),'filled')
        m_coast('color','k');
        m_grid('linestyle','none','fontsize',20);
        caxis([0 800])
        m_text(80, -54,'WOA13','Fontsize',20)
                
%% RSW PGW

for istep=1:size(list,1)
    % load data
    modeltemp=ncread([strcat(list(istep,:)) '/gridint_woa13_' strcat(list(istep,:)) '_thetao_tmean_1900-1999.nc'],'THETAONEW');
    modeltemp=modeltemp(ix,iy,:)-273.15; % change to celsius
    modelsal=ncread([strcat(list(istep,:)) '/gridint_woa13_' strcat(list(istep,:)) '_so_tmean_1900-1999.nc'],'SONEW');
    modelsal=modelsal(ix,iy,:);
    
    % sourcewatermass locations
    index_RSPGW=find(lon<=55 & lat>=11 &modeltemp>=RSPGW_temp1(istep)&modeltemp<=RSPGW_temp2(istep)&modelsal>=RSPGW_sal1(istep)&modelsal<=RSPGW_sal2(istep));
    
    figure
        m_proj('miller','lat',[-5 30],'lon',[30 79]);
        m_scatter(lon(index_RSPGW),lat(index_RSPGW),22,double(depth(index_RSPGW)),'filled')
        m_coast('color','k');
        m_grid('linestyle','none','fontsize',20);
        caxis([0 900])
        m_text(60, 0,['' strcat(list(istep,:)) ''],'Fontsize',20)
           
end

%woa
index_RSPGW=find(temp>18&sal>37.14);

figure
        m_proj('miller','lat',[-5 30],'lon',[30 79]);
        m_scatter(lon(index_RSPGW),lat(index_RSPGW),22,double(depth(index_RSPGW)),'filled')
        m_coast('color','k');
        m_grid('linestyle','none','fontsize',20);
        caxis([0 900])
        m_text(60, 0,['WOA13'],'Fontsize',20)

