%%
%-------------- new figure -----------------------
% Water mass analysis

% WOA 13
lon=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','lon');
lat=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','lat');
ix=find(lon>20 & lon<130); lon=lon(ix);
iy=find(lat>-60 &lat<30);  lat=lat(iy);
depth=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','depth');


% oxygen in ml/l
oxygen=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','o_an');
oxygen=oxygen(ix,iy,:,:)*40;  % in umol/l
% tempearture
temp=ncread('/Volumes/Geomar_data/WOA13/temperature/woa13_decav_t00_01v2.nc','t_an');
temp=temp(ix,iy,:,:);
% salinity
sal=ncread('/Volumes/Geomar_data/WOA13/salinity/woa13_decav_s00_01v2.nc','s_an');
sal=sal(ix,iy,:,:);
clear ix iy

% repmat data
lon=repmat(lon,1,length(lat),length(depth));
lat=permute(repmat(lat,1,size(lon,1),length(depth)),[2,1,3]);
depth=permute(repmat(depth,1,size(lon,1),size(lat,2)),[2,3,1]);
%% AS input
index_AS=find(lat>=16&lat<=22&lon<=67&lon>=61&depth>=150&depth<=1800);

sal_index_lit=[37.69 34.7 35.47 ]; %literature
temp_index_lit=[ 18.7 .38 18];

% restrict data to observational region
temp_c=temp(index_AS);
sal_c=sal(index_AS);
depth_c=depth(index_AS);
%% solve equations for wma (3 equations with 3 unknowns)

A = [sal_index_lit; temp_index_lit; [1 1 1]];
m = [];
for ii=1:length(sal_c)
    if ~isnan(sal_c(ii)*temp_c(ii))
        b=[sal_c(ii),temp_c(ii),1];
        m(ii,1:3) = b/A';
    else
        m(ii,1:3) = NaN;
    end
end
% clear values with negative water mass percentage
for istep=1:size(m,1)
    if m(istep,1)<0||m(istep,2)<0||m(istep,3)<0
        m(istep,:)=NaN;
    end
end
m_literature=m;

%% repeat for woa mean
sal_index_woa=[39.85 34.7 35.47 ];
temp_index_woa=[ 24.14 .38 15.8];

A = [sal_index_woa; temp_index_woa; [1 1 1]];
m = [];
for ii=1:length(sal_c)
    if ~isnan(sal_c(ii)*temp_c(ii))
        b=[sal_c(ii),temp_c(ii),1];
        m(ii,1:3) = b/A';
    else
        m(ii,1:3) = NaN;
    end
end
% clear values with negative water mass percentage
for istep=1:size(m,1)
    if m(istep,1)<0||m(istep,2)<0||m(istep,3)<0
        m(istep,:)=NaN;
    end
end

m_woamean=m;
%% figure 
fig=figure(3);
set(fig, 'Position',[541    38   900   767])

sp2=subplot(2,2,2);
scatter(m_literature(:,3)*100,depth(index_AS),35,[0.9451    0.7137    0.8549])
hold on
scatter(m_literature(:,2)*100,depth(index_AS),35,[0.4980    0.7373    0.2549])
scatter(m_literature(:,1)*100,depth(index_AS),35,[0.7725    0.1059    0.4902])
ylim([0 1800])
legend('\color[rgb]{0.9451,0.7137,0.8549}ICW','\color[rgb]{0.4980,0.7373,0.2549}IODW','\color[rgb]{0.7725,0.1059,0.4902}RSW/PGW','location','east')
legend boxoff
set(gca,'YDir','reverse', 'fontsize',20);
ylabel('Depth [m]', 'fontsize',20)
xlabel('Water mass fraction [%]','fontsize',20)
grid on
box on
text(90,130,'(b)','fontsize',20)

sp4=subplot(2,2,4);
scatter(m_woamean(:,3)*100,depth(index_AS),35,[0.9451    0.7137    0.8549])
hold on
scatter(m_woamean(:,2)*100,depth(index_AS),35,[0.4980    0.7373    0.2549])
scatter(m_woamean(:,1)*100,depth(index_AS),35,[0.7725    0.1059    0.4902])
ylim([0 1800])
legend('\color[rgb]{0.9451,0.7137,0.8549}ICW','\color[rgb]{0.4980,0.7373,0.2549}IODW','\color[rgb]{0.7725,0.1059,0.4902}RSW/PGW','location','east')
legend boxoff
set(gca,'YDir','reverse', 'fontsize',20);
ylabel('Depth [m]', 'fontsize',20)
xlabel('Water mass fraction [%]','fontsize',20)
grid on
box on
text(90,130,'(d)','fontsize',20)
%% TS diagram with sourchewatermass properties - see if the sourcewatermasses fit to the water volume chosen to resolve everything
sp1=subplot(2,2,1);
cm=[0.7725    0.1059    0.4902; 0.4980    0.7373    0.2549;0.9451    0.7137    0.8549];
scatter(sal_c(:),temp_c(:),20,depth_c(:))
hold on
cb1=colorbar;
ylabel('Potential temperature [?C]')
xlabel('Salinity')
xlim([34 40])
ylim([0 25])
caxis([0 1800])
set(gca,'Fontsize',20);
set(cb1,'Fontsize',20);
scatter(sal_index_lit,temp_index_lit,45,cm,'filled')
box on
text(35,1.5,'IODW','color',cm(2,:),'fontsize',20)
text(34.4,18,'ICW','color',cm(3,:),'fontsize',20)
text(37,17,'RSW/PGW','color',cm(1,:),'fontsize',20)
text(37.6,1.5,'Literature','color','k','fontsize',20)
text(39.3,23,'(a)','fontsize',20)


sp3=subplot(2,2,3);
scatter(sal_c(:),temp_c(:),20,depth_c(:))
hold on
cb2=colorbar;
ylabel('Potential temperature [?C]')
xlabel('Salinity')
xlim([34 40])
ylim([0 25])
caxis([0 1800])
set(gca,'Fontsize',20);
set(cb2,'Fontsize',20);
scatter(sal_index_woa,temp_index_woa,45,cm,'filled')
box on
text(35,1.5,'IODW','color',cm(2,:),'fontsize',20)
text(34.4,18,'ICW','color',cm(3,:),'fontsize',20)
text(37.8,20.5,'RSW/PGW','color',cm(1,:),'fontsize',20)
text(37.2,1.5,'Mean WOA13','color','k','fontsize',20)
text(39.3,23,'(c)','fontsize',20)


%% TS diagram

% WOA 13
lon=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','lon');
lat=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','lat');
ix=find(lon>20 & lon<130); lon=lon(ix);
iy=find(lat>-60 &lat<30);  lat=lat(iy);
depth=ncread('/Volumes/Geomar_data/WOA13/oxygen/woa13_all_o00_01.nc','depth');


% tempearture
temp=ncread('/Volumes/Geomar_data/WOA13/temperature/woa13_decav_t00_01v2.nc','t_an');
temp=temp(ix,iy,:,:);
% salinity
sal=ncread('/Volumes/Geomar_data/WOA13/salinity/woa13_decav_s00_01v2.nc','s_an');
sal=sal(ix,iy,:,:);
clear ix iy

depth=permute(repmat(depth,1,size(lon,1),size(lat,1)),[2,3,1]);
%%
fig=figure(4)
set(fig,'Position',[919   349   522   456]);
cm=[0.7725    0.1059    0.4902; 0.4980    0.7373    0.2549;0.9451    0.7137    0.8549];
scatter(sal(:),temp(:),20,depth(:))
hold on
cb1=colorbar;
ylabel('Potential temperature [?C]')
xlabel('Salinity')
xlim([26 42])
ylim([-5 35])
caxis([0 5000])
set(gca,'Fontsize',20);
set(cb1,'Fontsize',20);
box on
text(35.5,0,'IODW','color',cm(2,:),'fontsize',20)
text(32,15,'ICW','color',cm(3,:),'fontsize',20)
text(37.5,15,'RS/PGW','color',cm(1,:),'fontsize',20)
ylabel(cb1,'Depth [m]','Fontsize',20)

